@@ -1,6 +1,7 @@
 //! [POST /_matrix/client/r0/account/3pid/add](https://matrix.org/docs/spec/client_server/r0.6.1#post-matrix-client-r0-account-3pid-add)
 
 use ruma_api::ruma_api;
+use ruma_identifiers::{ClientSecret, SessionId};
 
 use crate::r0::uiaa::{AuthData, IncomingAuthData, UiaaResponse};
 
@@ -20,10 +21,10 @@ ruma_api! {
         pub auth: Option<AuthData<'a>>,
 
         /// Client-generated secret string used to protect this session.
-        pub client_secret: &'a str,
+        pub client_secret: &'a ClientSecret,
 
         /// The session identifier given by the identity server.
-        pub sid: &'a str,
+        pub sid: &'a SessionId,
     }
 
     #[derive(Default)]
@@ -34,7 +35,7 @@ ruma_api! {
 
 impl<'a> Request<'a> {
     /// Creates a new `Request` with the given client secret and session identifier.
-    pub fn new(client_secret: &'a str, sid: &'a str) -> Self {
+    pub fn new(client_secret: &'a ClientSecret, sid: &'a SessionId) -> Self {
         Self { auth: None, client_secret, sid }
     }
 }
